import java.io.*;
import java.util.*;
import java.util.logging.*;
import java.text.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class CurrencyConverter extends HttpServlet {
    private static final double EXCHANGE_RATE = 0.613;
	private static Logger convLogger = Logger.getLogger("convLogger");

	public void init() {
	    convLogger.setLevel(Level.INFO);
	    try {
		FileHandler logfile=new FileHandler("F:/Tomcat/logs/conv.log");
		logfile.setLevel(Level.INFO);
		logfile.setFormatter(new BasicFormatter());
		convLogger.addHandler(logfile);
		convLogger.setUseParentHandlers(false);
	    }
	    catch (IOException e) {
		convLogger.warning("Failed to set up logfile");
	    }
	}

	private String format (Currency currency, double value) {
	    NumberFormat nf = NumberFormat.getInstance();
	    nf.setMaximumFractionDigits(currency.getDefaultFractionDigits());
            nf.setMinimumFractionDigits(currency.getDefaultFractionDigits());
	    return nf.format(value);
	}

	public void doGet(HttpServletRequest req, HttpServletResponse res)
				 throws ServletException, IOException {

	    Currency dollars = Currency.getInstance(Locale.US);
	    Currency pounds = Currency.getInstance(Locale.UK);
	    try {
		double oldValue=Double.parseDouble(req.getParameter("amount"));
		if (oldValue <= 0) {
		req.setAttribute("error", "Value must be greater than zero");
		}
		else {
		    double newValue = oldValue * EXCHANGE_RATE ;
		    String result = dollars.getSymbol(Locale.US) +
		      format(dollars, oldValue) + " = "
		      + pounds.getSymbol(Locale.UK) + format(pounds, newValue);
		    req.setAttribute("result", result);
		    if (convLogger.isLoggable(Level.INFO)) {
		    convLogger.info("Converted " + result + " using rate " +
					   EXCHANGE_RATE);
		}
	    }
	    req.getRequestDispatcher ("/currency-form.jsp").forward(req, res);
	}
	catch (NumberFormatException e) {
	    req.setAttribute("error", "Non numeric value cannot be converted");
	    req.getRequestDispatcher ("/currency-form.jsp").forward(req, res);
	}
    }
}
