package converters;

import java.io.*;
import java.sql.*;
import javax.naming.*;
import javax.sql.*;
import java.util.*;

public class ConversionDAO
{
	private Connection con;
	private PreparedStatement select;
	private PreparedStatement update;
	private String src;
	private String dst;
	private double rate;

	public ConversionDAO() throws SQLException, NamingException
	{
		Context init = new InitialContext();
		Context ctx = (Context) init.lookup("java:comp/env");
		DataSource ds = (DataSource) ctx.lookup("jdbc/conversion");
		con = ds.getConnection();
		select = con.prepareStatement("SELECT rate FROM Exchange WHERE src = ? AND dst = ?");
		update = con.prepareStatement("UPDATE Exchange SET rate = ? WHERE src = ? AND dst = ?");
	}

	public String getSrc() { return src;}
	public String getDst() { return dst;}
	public double getRate() { return rate;}
	public void setSrc(String src) { this.src = src;}
	public void setDst(String dst) { this.dst = dst;}
	public void setRate(double rate) { this.rate = rate;}

	public double selectRate(String src, String dst) throws SQLException
	{
		ResultSet results = null;
		try {
			select.setString(1,src);
			select.setString(2,dst);
			results = select.executeQuery();
			if (!results.next())
				throw new SQLException("Missing Exchange rate data row");
			return results.getDouble(1);
		}
		finally {
			try { results.close(); } catch (Exception ex) {}
		}
	}

	public int updateRate() throws SQLException
	{
		if (src==null || dst==null)
			return 0;
		update.setDouble(1,rate);
		update.setString(2,src);
		update.setString(3,dst);
		return update.executeUpdate();
	}

	public void close()
	{
        try { select.close(); } catch (Exception ex) {}
        try { update.close(); } catch (Exception ex) {}
        try { con.close(); } catch (Exception ex) {}
    }
}
